package com.ynet.life.sujrb.file.parser;

import com.ynet.gene.core.Context;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.sujrb.file.BatchCorInfoSummary;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.FileConstants;
import java.io.FileInputStream;
import java.io.IOException;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.regex.Pattern;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/BatchCorInfoParser.class */
public class BatchCorInfoParser implements BatchFileParserInterface {
    private String formatter;
    private Context context;

    public BatchCorInfoParser() {
    }

    public BatchCorInfoParser(String formatter) {
        this.formatter = formatter;
    }

    public Context getContext() {
        return this.context;
    }

    public void setContext(Context context) {
        this.context = context;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        try {
            POIFSFileSystem file = new POIFSFileSystem(new FileInputStream(filePathName));
            HSSFWorkbook workBook = new HSSFWorkbook(file);
            BatchCorInfoSummary result = new BatchCorInfoSummary();
            new BigDecimal("0");
            try {
                HSSFSheet sheet = workBook.getSheetAt(0);
                sheet.getRow(0);
                int rowIndex = 2;
                HSSFRow recordRowTemp = sheet.getRow(2);
                if (getCellContent(recordRowTemp, 0, true).trim().equals("结束")) {
                    throw new TranFailException("excelError", "未导入企业数据");
                }
                while (true) {
                    int i = rowIndex;
                    rowIndex++;
                    HSSFRow recordRow = sheet.getRow(i);
                    if (!getCellContent(recordRow, 0, true).trim().equals("结束")) {
                        if (this.formatter == null) {
                            result.addRecord(getRecordMap(recordRow));
                        } else {
                            result.addRecord(getRecordMap(recordRow, this.formatter));
                        }
                    } else {
                        return result;
                    }
                }
            } catch (Exception ex) {
                Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
                throw FileConstants.EXCEPTION_PARSE_FAIL;
            }
        } catch (OfficeXmlFileException e) {
            Trace.logError("LifeFile", "Excel版本过高", e);
            throw new TranFailException("excelError", "Excel版本过高");
        } catch (IOException ex2) {
            Trace.logError("LifeFile", "文件读取失败", ex2);
            throw new TranFailException("excelError", "文件读取失败");
        }
    }

    private Map getRecordMap(HSSFRow recordRow) throws TranFailException {
        Map result = new HashMap();
        String pci_namecn = getCellContent(recordRow, 0, true);
        String orgcode = getCellContent(recordRow, 1, true);
        String companyType = getCellContent(recordRow, 2, true);
        String pci_branchno = getCellContent(recordRow, 3, true);
        String pci_con1name = getCellContent(recordRow, 4, true);
        String pci_con1tele = getCellContent(recordRow, 5, true);
        String pci_con1email = getCellContent(recordRow, 6, true);
        String remark = "";
        if ("".equals(pci_con1email) || pci_con1email == null) {
            remark = String.valueOf(remark) + " 联系人邮箱为空 ";
        } else if (!Pattern.compile("\\w+([-+.]\\w+)*@\\w+([-.]\\w+)*\\.\\w+([-.]\\w+)*").matcher(pci_con1email).matches()) {
            remark = String.valueOf(remark) + " 联系人邮箱不符合规则 ";
        }
        if ("".equals(pci_con1tele) || pci_con1tele == null) {
            remark = String.valueOf(remark) + " 联系人电话为空";
        } else if (!Pattern.compile("^1[\\d]{10}").matcher(pci_con1tele).matches()) {
            remark = String.valueOf(remark) + " 联系人电话不符合规则";
        }
        if ("".equals(pci_con1name) || pci_con1name == null) {
            remark = String.valueOf(remark) + " 联系人为空";
        } else if (!Pattern.compile("^[一-龥_a-zA-z]{1,50}").matcher(pci_con1name).matches()) {
            remark = String.valueOf(remark) + " 联系人名称不符合规则";
        }
        if ("".equals(pci_namecn) || pci_namecn == null) {
            remark = String.valueOf(remark) + " 企业名称为空";
        } else if (pci_namecn.length() > 50) {
            remark = String.valueOf(remark) + " 企业名称不符合规则";
        }
        if ("".equals(orgcode) || orgcode == null) {
            remark = String.valueOf(remark) + " 三证合一为空";
        } else if (!Pattern.compile("^[a-zA-Z0-9[-]]{8,20}").matcher(orgcode).matches()) {
            remark = String.valueOf(remark) + "三证合一证不符合规则";
        }
        if ("".equals(companyType) || companyType == null) {
            remark = String.valueOf(remark) + " 资本来源为空";
        } else if ("内地".equals(companyType)) {
            companyType = "0";
        } else if ("台湾".equals(companyType)) {
            companyType = "100";
        } else if ("港澳".equals(companyType)) {
            companyType = "200";
        } else if ("欧美".equals(companyType)) {
            companyType = "300";
        } else if ("其他".equals(companyType)) {
            companyType = "500";
        } else {
            remark = String.valueOf(remark) + " 资本来源不正确";
        }
        result.put("pci_namecn", pci_namecn);
        result.put("orgcode", orgcode);
        result.put("pci_con1name", pci_con1name);
        result.put("pci_con1tele", pci_con1tele);
        result.put("pci_branchno", pci_branchno);
        result.put("pci_state", "0");
        result.put("pci_pwd", "21218cca77804d2ba1922c33e0151105");
        result.put("remark", remark);
        result.put("companyType", companyType);
        result.put("pci_con1email", pci_con1email);
        return result;
    }

    private Map getRecordMap(HSSFRow recordRow, String formatter) throws TranFailException {
        Map result = new HashMap();
        StringTokenizer formatters = new StringTokenizer(formatter, "||");
        int i = 0;
        while (formatters.hasMoreTokens()) {
            String name = (String) formatters.nextElement();
            result.put(name, getCellContent(recordRow, i, true));
            i++;
        }
        return result;
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    private String getCellContent(HSSFRow row, int index, boolean toInt) throws TranFailException {
        String result = null;
        try {
            HSSFCell cell = row.getCell(index);
            switch (cell.getCellType()) {
                case 0:
                    String format = "######.##";
                    if (toInt) {
                        format = "#######";
                    }
                    result = new DecimalFormat(format).format(cell.getNumericCellValue());
                    break;
                case 1:
                    result = cell.getRichStringCellValue().getString();
                    break;
            }
            return result == null ? "" : result.trim();
        } catch (Exception ex) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
